@@ -22,7 +22,8 @@
 #include <gconf/gconf-client.h>
 #include <hildon/hildon-program.h>
 
-#define BULLET "\342\200\242 "
+/*#define BULLET "\342\200\242 "*/
+/*#define BULLET "\u2022 "*/
 
 typedef struct
 {
@@ -34,6 +35,7 @@ typedef struct
 	gint           font_size;
 	GConfClient   *client;
 	HildonProgram *program;
+	gboolean	   fullscreen;
 } AppData;
 
 typedef struct
@@ -48,12 +50,16 @@ typedef struct
 	GtkToggleToolButton *button_highlight;
 	GtkToggleToolButton *button_bullets;
 	
-	GtkCheckMenuItem    *menu_bold;
-	GtkCheckMenuItem    *menu_italic;
-	GtkCheckMenuItem	*menu_fixed;
-	GtkCheckMenuItem    *menu_strike;
-	GtkCheckMenuItem    *menu_highlight;
-	GtkCheckMenuItem    *menu_bullets;
+	GtkToggleAction     *action_bold;
+	GtkToggleAction     *action_italic;
+	GtkToggleAction	    *action_fixed;
+	GtkToggleAction     *action_strike;
+	GtkToggleAction     *action_highlight;
+	GtkToggleAction     *action_bullets;
+	GtkAction           *action_link;
+	GtkRadioAction		*action_font_small;
+	GtkAction			*action_inc_indent;
+	GtkAction			*action_dec_indent;
 
 } UserInterface;
 
@@ -75,11 +81,15 @@ typedef struct
   gboolean open_on_startup;
   const gchar *version;
   
+  GSList *active_tags;
+  
 } Note;
 
 AppData* get_app_data();
 
-/*AppData* init_app_data(const gchar *user_path);*/
+const gchar* get_bullet_by_depth(gint depth);
+
+const gchar* get_bullet_by_depth_tag(GtkTextTag *tag);
 
 GList* create_note_list(AppData *app_data);
 
